==> tdm_3.0.0.tar.gz: tdm/R/all.Imass.R <==
all.Imass<-function(){
     cat("\n")
     note_for_Imass_input()
     cat("\n")
     cat("****************************************************************\n")
     cat("      ATTENTION :                                               \n")
     cat("      Sampling Time (ts) must be greater than 1.5 hr.           \n")
     cat("****************************************************************\n")
     cat("\n\n")
     readline(" Press Enter to continue...\n")
     note_for_close_window()
     ### ImaSSpar<-data.frame(parameter=c("BW (kg)","OCC","Hb (g/dL)","WBC (10^9/L)","n","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))
     ImaSSpar<-data.frame(parameter=c("BW (kg)","OCC","Hb (g/dL)","WBC (10^9/L)","n","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),
                              value=c(67,1,12.1,110,10,400,24,3.6,2.81))
     ### ImaSSpar<-edit(ImaSSpar)   ### for model testing.  -YJ
     while(ImaSSpar[8,2]<1.5) {
        readline(" The parameter, ts (hr), must be greater than 1.5.\n Press Enter to fix it...")
        ImaSSpar<-edit(ImaSSpar)
     }
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(ImaSSpar);cat("\n\n")
     Ima.ss(ImaSSpar[9,2],ImaSSpar[7,2],ImaSSpar[8,2],ImaSSpar[5,2],ImaSSpar[6,2],ImaSSpar[2,2],ImaSSpar[1,2],ImaSSpar[3,2],ImaSSpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     note_for_Imass_output()
     ### show(samplesStats("*"))
     cat("\n") 
     C<-Imacpr(ImaSSpar[5,2],ImaSSpar[6,2],ImaSSpar[7,2],ImaSSpar[8,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Cm_pr (mg/L)")
     show(coutput);cat("\n\n")
     C<-Imasscpr(ImaSSpar[6,2],ImaSSpar[7,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput);cat("\n\n")
     Ima.more()
}

==> tdm_3.0.2.tar.gz: tdm/R/all.Imass.R <==
all.Imass<-function(){
     cat("\n")
     note_for_Imass_input()
     cat("\n")
     cat("****************************************************************\n")
     cat("      ATTENTION :                                               \n")
     cat("      Sampling Time (ts) must be greater than 1.5 hr.           \n")
     cat("****************************************************************\n")
     cat("\n\n")
     readline(" Press Enter to continue...\n")
     note_for_close_window()
     ### ImaSSpar<-data.frame(parameter=c("BW (kg)","OCC","Hb (g/dL)","WBC (10^9/L)","n","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),value=c(0))
     ImaSSpar<-data.frame(parameter=c("BW (kg)","OCC","Hb (g/dL)","WBC (10^9/L)","n","D (mg)","tau (hr)","ts (hr)","c (mg/L)"),
                              value=c(67,1,12.1,110,10,400,24,3.6,2.81))
     ImaSSpar<-edit(ImaSSpar)   ### for model testing.  -YJ
     while(ImaSSpar[8,2]<1.5) {
        readline(" The parameter, ts (hr), must be greater than 1.5.\n Press Enter to fix it...")
        ImaSSpar<-edit(ImaSSpar)
     }
     cat("\n Input data are as follows:\n")
     cat(" --------------------------\n")
     show(ImaSSpar);cat("\n\n")
     Ima.ss(ImaSSpar[9,2],ImaSSpar[7,2],ImaSSpar[8,2],ImaSSpar[5,2],ImaSSpar[6,2],ImaSSpar[2,2],ImaSSpar[1,2],ImaSSpar[3,2],ImaSSpar[4,2])
     note_for_convergence_plots()
     ### convergence_plots_sep()
     note_for_Imass_output()
     ### show(samplesStats("*"))
     cat("\n") 
     C<-Imacpr(ImaSSpar[5,2],ImaSSpar[6,2],ImaSSpar[7,2],ImaSSpar[8,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Cm_pr (mg/L)")
     show(coutput);cat("\n\n")
     C<-Imasscpr(ImaSSpar[6,2],ImaSSpar[7,2])
     ### sim<-matrix(C[1 ,1])
     coutput<-data.frame(C)
     colnames(coutput)<-list("Ctss_pr (mg/L)")
     show(coutput);cat("\n\n")
     Ima.more()
}
